@@ -8,7 +8,7 @@ from .args import Arguments
 from .util.color import Color
 from .util.logger import Logger
 from .util.database import Database
-from .version import __version__
+from .__meta__ import __version__
 
 class Configuration(object):
     ''' Stores configuration variables and functions for Turbo Search. '''
@@ -272,7 +272,7 @@ class Configuration(object):
                 Configuration.exit_gracefully(0)
 
         regex = re.compile(
-            r'^(?:http|ftp)s?://'  # http:// or https://
+            r'^(?:http|ftp|socks|socks5)s?://'  # http:// or https://
             r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|'  # domain...
             r'localhost|'  # localhost...
             r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})'  # ...or ip
